@@ -207,5 +207,6 @@ void TestXcbWindow::destroyNotManaged()
     QVERIFY(attribs);
 }
 
-KWIN_TEST_MAIN(TestXcbWindow)
+Q_CONSTRUCTOR_FUNCTION(forceXcb)
+QTEST_MAIN(TestXcbWindow)
 #include "test_xcb_window.moc"
